use serde::{Deserialize, Serialize};
use chrono::{DateTime, Utc};

#[derive(Clone, Deserialize, Serialize)]
pub struct Author {
    pub name: String,
    pub status: String,
    pub title: String,
    pub avatar_url: String,
    pub join_date: DateTime<Utc>,
}

#[derive(Clone, Deserialize, Serialize)]
pub struct Stats {
    pub views: i32,
    pub comments: i32,
    pub favorites: i32,
}

#[derive(Clone, Deserialize, Serialize)]
pub struct UserFolder {
    pub name: String,
    pub url: String,
    pub group: String,
}

#[derive(Clone, Deserialize, Serialize)]
pub struct Comment {
    pub id: i32,
    pub author: Author,
    pub date: DateTime<Utc>,
    pub text: String,
    pub replies: Vec<String>,
    pub reply_to: i32,
    pub edited: bool,
    pub hidden: bool,
}

#[derive(Clone, Deserialize, Serialize)]
pub struct Submission {
    pub id: i32,
    pub title: String,
    pub author: Author,
    pub date: DateTime<Utc>,
    pub tags: Vec<String>,
    pub category: String,
    pub species: String,
    pub gender: String,
    pub rating: String,
    #[serde(rename = "type")]
    pub submission_type: String,
    pub stats: Stats,
    pub description: String,
    pub footer: String,
    pub mentions: Vec<String>,
    pub folder: String,
    pub user_folders: Vec<UserFolder>,
    pub file_url: String,
    pub thumbnail_url: String,
    pub comments: Vec<Comment>,
    pub prev: i32,
    pub next: i32,
    pub favorite: bool,
    pub favorite_toggle_link: String,
}